=======
History
=======

0.2.0 (2019-07-27)
------------------

* Add `is_youtube` function to check if a URL belongs to a recognized YouTube domain.
* Add type hints to ytu functions and drop Python 3.4 support accordingly.
* Rename `get_param_value` to `param_value`.

0.1.0 (2019-07-27)
------------------

* First release on PyPI.
